@@ -56,7 +56,7 @@ meta_finish_workspace_switch (MetaCompScreen *info)
 
 }
 
-void
+LOCAL_SYMBOL void
 meta_switch_workspace_completed (MetaScreen *screen)
 {
   MetaCompScreen *info = meta_screen_get_compositor_data (screen);
@@ -231,6 +231,23 @@ meta_get_window_group_for_screen (MetaScreen *screen)
   return info->window_group;
 }
 
+/**
+ * meta_get_bottom_window_group_for_screen:
+ * @screen: a #MetaScreen
+ *
+ * Returns: (transfer none): The bottom window group corresponding to @screen
+ */
+ClutterActor *
+meta_get_bottom_window_group_for_screen (MetaScreen *screen)
+{
+  MetaCompScreen *info = meta_screen_get_compositor_data (screen);
+
+  if (!info)
+    return NULL;
+
+  return info->bottom_window_group;
+}
+
 /**
  * meta_get_top_window_group_for_screen:
  * @screen: a #MetaScreen
@@ -351,7 +368,7 @@ meta_empty_stage_input_region (MetaScreen *screen)
   meta_set_stage_input_region (screen, region);
 }
 
-gboolean
+LOCAL_SYMBOL gboolean
 meta_begin_modal_for_plugin (MetaScreen       *screen,
                              MetaPlugin       *plugin,
                              Window            grab_window,
@@ -421,7 +438,7 @@ meta_begin_modal_for_plugin (MetaScreen       *screen,
   return FALSE;
 }
 
-void
+LOCAL_SYMBOL void
 meta_end_modal_for_plugin (MetaScreen     *screen,
                            MetaPlugin     *plugin,
                            guint32         timestamp)
@@ -447,7 +464,7 @@ meta_end_modal_for_plugin (MetaScreen     *screen,
 /* This is used when reloading plugins to make sure we don't have
  * a left-over modal grab for this screen.
  */
-void
+LOCAL_SYMBOL void
 meta_check_end_modal (MetaScreen *screen)
 {
   MetaDisplay    *display    = meta_screen_get_display (screen);
@@ -559,6 +576,7 @@ meta_compositor_manage_screen (MetaCompositor *compositor,
 
   info->window_group = meta_window_group_new (screen);
   info->background_actor = meta_background_actor_new_for_screen (screen);
+  info->bottom_window_group = clutter_group_new();
   info->overlay_group = clutter_group_new ();
   info->top_window_group = meta_window_group_new (screen);
   info->hidden_group = clutter_group_new ();
